Coverage for appr/commands/delete_package.py: 39%

# Coverage for appr/commands/delete_package.py : 39%

## 28 statements 11 run 17 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 | from __future__ import absolute_import, division, print_function import os from appr.commands.command_base import CommandBase class DeletePackageCmd(CommandBase): name = 'delete-package' help_message = 'delete package from the registry' def __init__(self, options): super(DeletePackageCmd, self).__init__(options) self.package = options.package self.registry_host = options.registry_host self.version = options.version self.media_type = options.media_type if options.media_type is self.default_media_type: self.media_type = os.getenv("APPR_DEFAULT_MEDIA_TYPE", self.default_media_type) self.result = None self.ssl_verify = options.cacert or not options.insecure @classmethod def _add_arguments(cls, parser): cls._add_registryhost_option(parser) cls._add_mediatype_option(parser) cls._add_packagename_option(parser) cls._add_packageversion_option(parser) def _call(self): client = self.RegistryClient(self.registry_host, requests_verify=self.ssl_verify) self.result = client.delete_package(self.package, version=self.version, media_type=self.media_type) def _render_dict(self): return self.result def _render_console(self): return "Deleted package: %s - %s" % (self.result['package'], self.result['release'])